#!/usr/bin/env python
#coding=utf-8

import onelab, sys

OL = onelab.client(__file__)

# Display the geometry /mesh  in the GUI
#--------------------------------------
OL.openProject(OL.checkPath('pois.geo'))

if OL.action == 'check':
    OL.run('mesher', 'gmsh - ' +  OL.checkPath('pois.geo'),'')
    
# Define additional Onelab parameters
#--------------------------------------
FLOWPROFILE = OL.defineNumber('2Fluid/1FLOWPROFILE', value=1, label = 'Flow profile',
    labels={1:'Flat',
            2:'Parabolic'})
VMEAN = OL.defineNumber('2Fluid/2VMEAN', value =0.5, label='Mean velocity (m/s)')
MU  = OL.defineNumber('2Fluid/3MU', value = 0.01, label ='Viscosity (Pa.s)')
RHO = OL.defineNumber('2Fluid/4RHO', value = 100.0, label= 'Density (kg/m^3)')

rad = OL.getNumber('1Geometry/R')
reynolds  = OL.getNumber('2Fluid/4RHO')*OL.getNumber('2Fluid/2VMEAN')*2.*rad/OL.getNumber('2Fluid/3MU')
flowrate  = OL.getNumber('2Fluid/2VMEAN')*3.14*rad*rad
tauw = (4.*OL.getNumber('2Fluid/3MU')/rad)*OL.getNumber('2Fluid/2VMEAN')
gamma = tauw/OL.getNumber('2Fluid/3MU')

ld = OL.getNumber('1Geometry/L')
if FLOWPROFILE == 1:
    ld = 0.06*2.*rad*reynolds
           
OL.setNumber('2Fluid/5REYNOLDS',
             value=reynolds, readOnly=1,
             label='Reynolds',
             attributes={'Highlight':'AliceBlue'})

OL.setNumber('2Fluid/6FLOWRATE',
             value=flowrate, readOnly=1,
             label='Flow rate (m^3/s)',
             attributes={'Highlight':'AliceBlue'})

OL.defineNumber('3AnalyticSolution/1TAUW', label='Shear stress [Pa]',
            value=tauw, readOnly=1,
            attributes={'Highlight':'AliceBlue'})

OL.defineNumber('3AnalyticSolution/2GAMMA', label='Shear rate [1/s]',
            value=gamma,  readOnly=1,
            attributes={'Highlight':'AliceBlue'})

OL.defineNumber('3AnalyticSolution/3LD', label='Development length [m]',
            value=ld, readOnly=1,
            attributes={'Highlight':'AliceBlue'})

if FLOWPROFILE == 2 :
    OL.setNumber('3AnalyticSolution/3LD', visible=0)
else :
    OL.setNumber('3AnalyticSolution/3LD', visible=1)

if reynolds > 2400 :
    print("Reynolds number is too large for laminar flow : Re= %g \n" ,reynolds)

# Pre process
#----------------
OL.preProcess('elmer', OL.checkPath('pois.sif.ol'))
OL.preProcess('postpro', OL.checkPath('script.opt.ol'))
     
# Start solvers
#----------------
# we're done with the "check" phase
if OL.action == 'check' :
    exit(1)
     
# Mesh the geometry and Display the mesh in the GUI
OL.run('mesher', 'gmsh - ' +  OL.checkPath('pois.geo'),'-3')
OL.mergeFile(OL.checkPath('pois.msh'))

# Nonnative clients are called with OL.call
OL.call('grid','ElmerGrid 14 2 pois.msh -out mesh', rundir=OL.wdir)
OL.call('elmer','ElmerSolver pois.sif', rundir=OL.wdir)
OL.mergeFile(OL.checkPath('solution.pos'))

OL.call('postpro','gmsh solution.pos script.opt -', rundir=OL.wdir)

if not OL.batch:
    OL.call('plot','gnuplot plot.plt -persist', rundir=OL.wdir) 

#postpro
#--------


shearNUM = abs( onelab.extract(OL.checkPath('shear.txt'), -1, 1) )

#last_line = file("shear.txt", "r").readlines()[-1]
#columns = last_line.split()
#shearNUM = abs(float(columns[0]))

OL.defineNumber('4NumericalSolution/SHEARNUM', readOnly=1, 
                attributes={'Highlight':'Coral'},
                label='Shear stress end [Pa]')
OL.addNumberChoice('4NumericalSolution/SHEARNUM', shearNUM)


if OL.batch:
    sys.stderr.write('%s: shearNUM = %12.5e (%12.5e)\n' %
                     (__file__, shearNUM, 3.5485525347635125))
    

    
