
!*********** Variables ************
$vmean  = OL.get(2Fluid/2VMEAN)
$rho = OL.get(2Fluid/4RHO)
$mu  = OL.get(2Fluid/3MU)
$rad = OL.get(1Geometry/R)

!*********** Variables ***********

Header
  Mesh DB "." "mesh"
  Include Path ""
  Results Directory ""
End

Simulation
  Coordinate System = Axi Symmetric 
  Simulation Type = Steady
  Steady State Max Iterations = 20
  Output Intervals = 1
End

Body 1
  Equation = 1
  Material = 1
End

Material 1
  Density = Real $rho
  Viscosity = Real $mu
End

Equation 1
  Navier-Stokes = True
  Active Solvers(3) = 1 2 3
End

Solver 1
  Equation =  Navier-Stokes
  Linear System Solver = Iterative
  Linear System Iterative Method = BiCGStab
  Linear System Max Iterations = 500
  Linear System Convergence Tolerance = 1.0e-8
  Linear System Preconditioning = ILU0
  Linear System Residual Output = 1
  Steady State Convergence Tolerance = 1.0e-5
  Stabilize = True
  Nonlinear System Convergence Tolerance = 1.0e-10
  Nonlinear System Max Iterations = 5
  Nonlinear System Newton After Iterations = 3
  Nonlinear System Newton After Tolerance = 1.0e-2
  Nonlinear System Relaxation Factor = 1.0
  Calculate Loads = Logical True
End

Solver 2
   Exec solver = After All
   Equation = String "ResultOutput"
   Procedure = File "ResultOutputSolve" "ResultOutputSolver"
   Output File Name = File "solution.pos"
   Output Format = String gmsh
   Scalar Field 1 =  String Pressure
   Vector Field 1 =  String flow solution	
End

Solver 3
  Exec Solver = After All
  Equation = Fluidic Force
  Procedure ="FluidicForce" "ForceCompute"
  Calculate Viscous Force = True
  !Sum Forces = True
  Shear Stress Output = True
  Shear Stress Output File = "shear.txt" 
end

Boundary Condition 1
  Name = "Symmetry"
  Target Boundaries(1) = 4
  !Velocity 1 = 0.0 ! normal velocity
  !Velocity 2 = Variable "Coordinate 1" 
  !   MATC "2*vmean" ! tangential velocity
  !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
  ! si ui  = mu du/dn
  !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
  Normal-Tangential Velocity = True 
  Velocity 1 = 0;
  Slip Coefficient 2 = 0;
End

Boundary Condition 2
  Name = "Outlet"
  Target Boundaries(1) = 3
  Pressure = 0
  Velocity 1 = 0
End

Boundary Condition 3
  Name = "Inlet"
  Target Boundaries(1) = 1
  Velocity 1 = 0.0
  Velocity 2 = Variable "Coordinate 1" 
OL.if( OL.get(2Fluid/1FLOWPROFILE) == 1) 
   Real MATC "vmean"  
OL.else
   Real MATC "2*vmean*(1-(tx*tx)/(rad*rad))"
OL.endif
End

Boundary Condition 4
  Name = "No-slip"
  Target Boundaries(1) = 2
  Normal-Tangential Velocity = True 
  Velocity 1 = 0.0 ! normal velocity
  Velocity 2 = 0.0 ! tangential velocity
  Calculate Fluidic Force = True
End



